@@ -7,7 +7,6 @@ Created on 23.3.2010
 from m3_ext.ui.base import ExtUIComponent
 
 
-#==============================================================================
 class ExtLabel(ExtUIComponent):
     """
     Произвольный текст
@@ -22,7 +21,7 @@ class ExtLabel(ExtUIComponent):
 
         self.init_component(*args, **kwargs)
 
-    def make_read_only(
-            self, access_off=True, exclude_list=[], *args, **kwargs):
+    def _make_read_only(
+            self, access_off=True, exclude_list=None, *args, **kwargs):
         # Описание в базовом классе ExtUiComponent.
         pass
